==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translatorcomment>--exact match--
--file: Dimension_pt.ts--
&amp;Dimensão
Dimensão
Dimensão Alinhada</translatorcomment>
        <translation>Cota</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cotas configurações padrão</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Configurações cotas</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Padrões para novos desenhos</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Scientific</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Científico</translatorcomment>
        <translation>Científico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Decimal
Graus Decimais</translatorcomment>
        <translation>Decimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Engenharia
Para comprimentos formatados como &apos;Engenharia&apos; ou &apos;Arquitetura&apos;, a unidade deve ser polegada.</translatorcomment>
        <translation>Engenharia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Arquitetura
Para comprimentos formatados como &apos;Engenharia&apos; ou &apos;Arquitetura&apos;, a unidade deve ser polegada.</translatorcomment>
        <translation>Arquitetura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Fracionais</translatorcomment>
        <translation>Fracionais</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Decimal Degrees</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Graus Decimais</translatorcomment>
        <translation>Graus decimais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Grau/min/seg</translatorcomment>
        <translation>Grau/min/seg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Gradianos</translatorcomment>
        <translation>Gradianos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Gradianos
Radianos</translatorcomment>
        <translation>Radianos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Unidades de topógrafo</translatorcomment>
        <translation>Unidades de topógrafo</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Unit / Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Unidade / format</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>A unidade de desenho deve ser &apos;Inch&apos; para exibir cotas em formatos &apos;Arquitetura&apos; ou &apos;Engenharia&apos;. Formato alterado para &apos;decimal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tamanhos
Tamanhos das imagens</translatorcomment>
        <translation>Tamanhos</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: Image_pt.ts--
Mantenha proporções</translatorcomment>
        <translation>Mantenha proporções</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Altura do Texto:</translatorcomment>
        <translation>Altura do texto:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Extensão da linha de deslocamento:</translatorcomment>
        <translation>Extensão da linha de deslocamento:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Extensão da linha de extensionamento:</translatorcomment>
        <translation>Extensão da linha de extensionamento:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Dimensione a linha de brecha:</translatorcomment>
        <translation>Linha de cota brecha:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tamanho da seta:</translatorcomment>
        <translation>Tamanho da seta:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Fator de escala:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translatorcomment>--google--
Estilo da Seta:
Estilo da Seta</translatorcomment>
        <translation>Estilo da seta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Conduza (seqüência linear com seta)
Tamanho da seta:</translatorcomment>
        <translation>Seta</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Espessura Arquitetônica</translatorcomment>
        <translation>Espessura arquitetônica</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Label Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Formato etiqueta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas lineares</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Formato:</translatorcomment>
        <translation>&amp;Formato:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Precisão:</translatorcomment>
        <translation>P&amp;recisão:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Exibe zeros à esquerda</translatorcomment>
        <translation>Exibe zeros à esquerda</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas angulares</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Formato:</translatorcomment>
        <translation>F&amp;ormato:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pre&amp;cisão:</translatorcomment>
        <translation>Pre&amp;cisão:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de Impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation>Pré-visualizar</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translatorcomment>--exact match--
--file: Dimension_pt.ts--
&amp;Dimensão
Dimensão
Dimensão Alinhada</translatorcomment>
        <translation>Dimensão</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cotas configurações padrão</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Configurações de Dimensões</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Padrões para Novos Desenhos</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Scientific</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Científico</translatorcomment>
        <translation>Científico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Decimal
Graus Decimais</translatorcomment>
        <translation>Decimal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Engenharia
Para comprimentos formatados como &apos;Engenharia&apos; ou &apos;Arquitetura&apos;, a unidade deve ser polegada.</translatorcomment>
        <translation>Engenharia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Arquitetura
Para comprimentos formatados como &apos;Engenharia&apos; ou &apos;Arquitetura&apos;, a unidade deve ser polegada.</translatorcomment>
        <translation>Arquitetura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Fracionais</translatorcomment>
        <translation>Frações</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Graus Decimais</translatorcomment>
        <translation>Graus Decimais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Grau/min/seg</translatorcomment>
        <translation>Grau/min/seg</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Gradianos</translatorcomment>
        <translation>Gradianos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Gradianos
Radianos</translatorcomment>
        <translation>Radianos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Unidades de topógrafo</translatorcomment>
        <translation>Unidades de topografia</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>Unit / Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Unidade / Formato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>A unidade de desenho deve ser &apos;Polegada&apos; ou &apos;Pé&apos; para exibir rótulos de dimensões nos formatos &apos;Arquitetura&apos; ou &apos;Engenharia&apos;. Formato alterado para &apos;Decimal&apos;.</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">A unidade de desenho deve ser &apos;Polegada&apos; para exibir rótulos de dimensões em formatos &apos;Arquitetura&apos; ou &apos;Engenharia&apos;. Formato alterado para &apos;Decimal&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tamanhos
Tamanhos das imagens</translatorcomment>
        <translation>Tamanhos</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: Image_pt.ts--
Mantenha proporções</translatorcomment>
        <translation>Mantenha proporções</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Altura do Texto:</translatorcomment>
        <translation>Altura do texto:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Extensão da linha de deslocamento:</translatorcomment>
        <translation>Extensão da linha de offset:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Extensão da linha de extensionamento:</translatorcomment>
        <translation>Extensão da linha estendida:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Dimensione a linha de brecha:</translatorcomment>
        <translation>Lacuna da linha de dimensão:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Tamanho da seta:</translatorcomment>
        <translation>Tamanho da seta:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Fator de escala:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translatorcomment>--google--
Estilo da Seta:
Estilo da Seta</translatorcomment>
        <translation>Estilo da Seta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Conduza (seqüência linear com seta)
Tamanho da seta:</translatorcomment>
        <translation>Seta</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Espessura Arquitetônica</translatorcomment>
        <translation>Ponto Arquitetônico</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Fonte do rótulo de dimensões:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Formato do rótulo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões Lineares</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Formato:</translatorcomment>
        <translation>&amp;Formato:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Precisão:</translatorcomment>
        <translation>P&amp;recisão:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Exibe zeros à esquerda</translatorcomment>
        <translation>Exiba zeros à esquerda</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dimensões Angulares</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Formato:</translatorcomment>
        <translation>F&amp;ormato:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Pre&amp;cisão:</translatorcomment>
        <translation>Pre&amp;cisão:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Prévia de impressão para %1
Prévia de Impressão
Exibe uma prévia da impressão</translatorcomment>
        <translation>Pré-visualização</translation>
    </message>
</context>
</TS>
